==> haskell-invariant-0.6.4-89.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-DQVW85wmN9o2zzRL81vdJd
key:                  invariant-0.6.4-DQVW85wmN9o2zzRL81vdJd
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  dc9b98c33a47084fec9956f9e51d80f3
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-DQVW85wmN9o2zzRL81vdJd
depends:
    StateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb array-0.5.6.0 base-4.18.2.1
    bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
    comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW ghc-prim-0.10.0
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.4-90-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-HfDfTohAQvFGFCMlyLEpl3
key:                  invariant-0.6.4-HfDfTohAQvFGFCMlyLEpl3
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  3dfd32d0187bb3a0f7a13782684e8971
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-HfDfTohAQvFGFCMlyLEpl3
depends:
    StateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb array-0.5.6.0 base-4.18.2.1
    bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
    comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW ghc-prim-0.10.0
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
